@@ -266,15 +266,19 @@ function generateModuleByName(moduleName,defines,sideName){
 function generateFramework(defines,param){
     initPathEnv(defines);
     generateFrameworkDirectories();
-    copyFrameworkFiles();
+    //copyFrameworkFiles();
     copyReleaseFrameworkFiles();
 }
+function generateCommon(sideName){
+    copyFrameworkFiles();
+}
 function initProjectEnv(defines){
     initPathEnv(defines);
 }
 
 exports.generateFramework = generateFramework;
 exports.generateModuleByName = generateModuleByName;
+exports.generateCommon = generateCommon;
 exports.initEnv = initPathEnv;
 
 exports.coderDefine = {name:"rj",desc:"create a react js framework and related project code"};
